.. _promotion:

Promoting the translation
=========================

Weblate provides you widgets to share on your website or other sources to
promote the translation project. It also has a nice welcome page for new contributors
to give them basic information about the translation. Additionally you can
share information about translation using Facebook or Twitter. All these
possibilities can be found on the :guilabel:`Share` tab. Example of status badges
for Weblate itself are shown below.

Shields.IO badge often used to quickly see status of a project:

.. image:: ../images/weblate-shields-badge.*
    :alt: Translation status
    :target: https://hosted.weblate.org/engage/weblate/?utm_source=widget

Small badge often used to quickly see status of a project:

.. image:: ../images/weblate-status-badge.png
    :alt: Translation status
    :target: https://hosted.weblate.org/engage/weblate/?utm_source=widget

Big badge with status details useful for inclusion on a web page:

.. image:: ../images/weblate-287x66-white.png
    :alt: Translation status
    :target: https://hosted.weblate.org/engage/weblate/?utm_source=widget

Small badge with status useful for inclusion on a web page:

.. image:: ../images/weblate-88x31-grey.png
    :alt: Translation status
    :target: https://hosted.weblate.org/engage/weblate/?utm_source=widget

All these badges come with links to simple page which explains users how to
translate using Weblate:

.. image:: ../images/engage.png
